@@ -39,4 +39,14 @@ def deserialize_match(d: Dict) -> BrokerMatch:
     :param d: Dictionary to convert
     :return: Converted dictionary
     """
-    return BrokerMatch(d["bit-string"], d["confidence"])
+    return BrokerMatch(d["bit-vector"], d["confidence"])
+
+
+def deserialize_secret_response(d: Dict) -> str:
+    """
+    Extracts a secret from a dictionary.
+
+    :param d: Dictionary to extract secret from
+    :return: Extracted secret
+    """
+    return d["secret"]
\ No newline at end of file
