@@ -106,25 +106,9 @@ def serialize_encoder_request(request: EncoderRequest) -> Dict:
     if len(request.entity_list) == 0:
         return {}
 
-    # mapping of attr name -> schema. add all existing schemas to this dict.
-    schema_dict: Dict[str, AttributeSchema] = {
-        s.attribute_name: s for s in request.schema_list
-    }
-
-    # iterate over all attribute of the first entity to add data types
-    for attr in request.entity_list[0].attributes:
-        data_type_dict = {"data-type": attr.resolve_data_type()}
-
-        # create a new entry if this attribute doesn't exist yet
-        if attr.name not in schema_dict:
-            schema_dict[attr.name] = AttributeSchema(attr.name, data_type_dict)
-        # otherwise just update the existing dict with the attribute data type
-        else:
-            schema_dict[attr.name].options.update(data_type_dict)
-
     d = serialize_encoder_config(request.config)
     d["entity-list"] = serialize_entities(request.entity_list)
-    d["schema-list"] = serialize_schemas(list(schema_dict.values()))
+    d["schema-list"] = serialize_schemas(list(request.schema_list))
 
     return d
 
