@@ -1,4 +1,5 @@
 from dataclasses import dataclass, field
+import copy
 import datetime
 from typing import List, Dict
 
@@ -57,6 +58,16 @@ class AttributeSchema:
     attribute_name: str
     options: Dict[str, object] = field(default_factory=dict)
 
+    @staticmethod
+    def with_data_type(attribute_name: str, data_type: str, options: Dict[str, object] = None):
+        if options is None:
+            options = {}
+
+        cloned_opts = copy.deepcopy(options)
+        cloned_opts.update({"data-type": data_type})
+
+        return AttributeSchema(attribute_name, cloned_opts)
+
 
 @dataclass(frozen=True)
 class Entity:
